==> zio-aws-transfer_2.12-5.17.158.1-sources.jar: zio/aws/transfer/model/ListAccessesRequest.scala <==
package zio.aws.transfer.model
import zio.aws.transfer.model.primitives.{ServerId, NextToken, MaxResults}
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListAccessesRequest(
    maxResults: Option[MaxResults] = None,
    nextToken: Option[NextToken] = None,
    serverId: ServerId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transfer.model.ListAccessesRequest = {
    import ListAccessesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transfer.model.ListAccessesRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .serverId(ServerId.unwrap(serverId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.transfer.model.ListAccessesRequest.ReadOnly =
    zio.aws.transfer.model.ListAccessesRequest.wrap(buildAwsValue())
}
object ListAccessesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transfer.model.ListAccessesRequest =
      zio.aws.transfer.model.ListAccessesRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        serverId
      )
    def maxResults: Option[MaxResults]
    def nextToken: Option[NextToken]
    def serverId: ServerId
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getServerId: ZIO[Any, Nothing, ServerId] = ZIO.succeed(serverId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ) extends zio.aws.transfer.model.ListAccessesRequest.ReadOnly {
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.transfer.model.primitives.MaxResults(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.transfer.model.primitives.NextToken(value))
    override val serverId: ServerId =
      zio.aws.transfer.model.primitives.ServerId(impl.serverId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ): zio.aws.transfer.model.ListAccessesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-transfer_2.12-7.28.29.3-sources.jar: zio/aws/transfer/model/ListAccessesRequest.scala <==
package zio.aws.transfer.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.transfer.model.primitives.{ServerId, NextToken, MaxResults}
import scala.jdk.CollectionConverters._
final case class ListAccessesRequest(
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    serverId: ServerId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.transfer.model.ListAccessesRequest = {
    import ListAccessesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.transfer.model.ListAccessesRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .serverId(ServerId.unwrap(serverId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.transfer.model.ListAccessesRequest.ReadOnly =
    zio.aws.transfer.model.ListAccessesRequest.wrap(buildAwsValue())
}
object ListAccessesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.transfer.model.ListAccessesRequest =
      zio.aws.transfer.model.ListAccessesRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        serverId
      )
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[NextToken]
    def serverId: ServerId
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getServerId: ZIO[Any, Nothing, ServerId] = ZIO.succeed(serverId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ) extends zio.aws.transfer.model.ListAccessesRequest.ReadOnly {
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.transfer.model.primitives.MaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.transfer.model.primitives.NextToken(value))
    override val serverId: ServerId =
      zio.aws.transfer.model.primitives.ServerId(impl.serverId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.transfer.model.ListAccessesRequest
  ): zio.aws.transfer.model.ListAccessesRequest.ReadOnly = new Wrapper(impl)
}
